@@ -25,7 +25,7 @@
 
 class PalmDocExport : public KoFilter
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
   public:
