@@ -23,7 +23,7 @@ class TQTimer;
 
 class QueueTuner: public QueueTunerBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
