@@ -48,10 +48,10 @@ static int dbcount  = 0;
 static int dbcustomcount = 200;
 static TQStrList *wGroups;
 static TQStrList *invisibleGroups;
-static bool whatsThisLoaded = FALSE;
+static bool whatsThisLoaded = false;
 static TQPluginManager<WidgetInterface> *widgetPluginManager = 0;
-static bool plugins_set_up = FALSE;
-static bool was_in_setup = FALSE;
+static bool plugins_set_up = false;
+static bool was_in_setup = false;
 
 TQCleanupHandler<TQPluginManager<WidgetInterface> > cleanup_manager;
 
@@ -101,7 +101,7 @@ WidgetDatabase::WidgetDatabase()
 
 void WidgetDatabase::setupDataBase( int id )
 {
-    was_in_setup = TRUE;
+    was_in_setup = true;
 #ifndef UIC
     Q_UNUSED( id )
     if ( dbcount )
@@ -122,7 +122,7 @@ void WidgetDatabase::setupDataBase( int id )
     invisibleGroups->append( "Forms" );
     invisibleGroups->append( "Temp" );
     className2Id = new TQDict<int>( dbdictsize );
-    className2Id->setAutoDelete( TRUE );
+    className2Id->setAutoDelete( true );
 
     WidgetDatabaseRecord *r = 0;
 
@@ -574,7 +574,7 @@ void WidgetDatabase::setupPlugins()
 {
     if ( plugins_set_up )
 	return;
-    plugins_set_up = TRUE;
+    plugins_set_up = true;
     TQStringList widgets = widgetManager()->featureList();
     for ( TQStringList::Iterator it = widgets.begin(); it != widgets.end(); ++it ) {
 	if ( hasWidget( *it ) )
@@ -724,7 +724,7 @@ bool WidgetDatabase::isForm( int id )
     setupDataBase( id );
     WidgetDatabaseRecord *r = at( id );
     if ( !r )
-	return FALSE;
+	return false;
     return r->isForm;
 }
 
@@ -736,7 +736,7 @@ bool WidgetDatabase::isContainer( int id )
     setupDataBase( id );
     WidgetDatabaseRecord *r = at( id );
     if ( !r )
-	return FALSE;
+	return false;
     return r->isContainer || r->isForm;
 }
 
@@ -745,7 +745,7 @@ bool WidgetDatabase::isCommon( int id )
     setupDataBase( id );
     WidgetDatabaseRecord *r = at( id );
     if ( !r )
-	return FALSE;
+	return false;
     return r->isCommon;
 }
 
@@ -837,9 +837,9 @@ bool WidgetDatabase::isGroupEmpty( const TQString &grp )
 	if ( !( r = db[ i ] ) )
 	    continue;
 	if ( r->group == grp )
-	    return FALSE;
+	    return false;
     }
-    return TRUE;
+    return true;
 }
 
 TQString WidgetDatabase::widgetGroup( int i )
@@ -883,8 +883,8 @@ void WidgetDatabase::customWidgetClassNameChanged( const TQString &oldName,
 bool WidgetDatabase::isCustomWidget( int id )
 {
     if ( id >= dbcustom && id < dbcustomcount )
-	return TRUE;
-    return FALSE;
+	return true;
+    return false;
 }
 
 bool WidgetDatabase::isCustomPluginWidget( int id )
@@ -892,7 +892,7 @@ bool WidgetDatabase::isCustomPluginWidget( int id )
     setupDataBase( id );
     WidgetDatabaseRecord *r = at( id );
     if ( !r )
-	return FALSE;
+	return false;
     return r->isPlugin;
 }
 
@@ -916,13 +916,13 @@ void WidgetDatabase::loadWhatsThis( const TQString &docPath )
 	if ( r )
 	    r->whatsThis = l[ 0 ];
     }
-    whatsThisLoaded = TRUE;
+    whatsThisLoaded = true;
 }
 
 
 // ### TQt 3.1: make these publically accessible via TQWidgetDatabase API
 #if defined(UIC)
-bool dbnounload = FALSE;
+bool dbnounload = false;
 TQStringList *dbpaths = 0;
 #else
 extern TQString *qwf_plugin_dir;
@@ -941,7 +941,7 @@ TQPluginManager<WidgetInterface> *widgetManager()
 	cleanup_manager.add( &widgetPluginManager );
 #if defined(UIC)
 	if ( dbnounload )
-	    widgetPluginManager->setAutoUnload( FALSE );
+	    widgetPluginManager->setAutoUnload( false );
 	if ( dbpaths ) {
 	    TQStringList::ConstIterator it = dbpaths->begin();
 	    for ( ; it != dbpaths->end(); ++it )
