@@ -78,7 +78,7 @@ NoteInserter::NoteInserter(NotationView* view)
 
     TDEToggleAction *autoBeamAction =
         new TDEToggleAction(i18n("Auto-Beam when appropriate"), 0, this,
-                          TQT_SLOT(slotToggleAutoBeam()), actionCollection(),
+                          TQ_SLOT(slotToggleAutoBeam()), actionCollection(),
                           "toggle_auto_beam");
     autoBeamAction->setChecked(m_autoBeam);
 
@@ -99,30 +99,30 @@ NoteInserter::NoteInserter(NotationView* view)
            (NotePixmapFactory::toTQPixmap(NotePixmapFactory::
                                          makeToolbarPixmap("dotted-crotchet")));
     new TDEToggleAction(i18n("Dotted note"), icon, 0, this,
-                      TQT_SLOT(slotToggleDot()), actionCollection(),
+                      TQ_SLOT(slotToggleDot()), actionCollection(),
                       "toggle_dot");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::
                     makeToolbarPixmap("select")));
     new TDEAction(i18n("Switch to Select Tool"), icon, 0, this,
-                TQT_SLOT(slotSelectSelected()), actionCollection(),
+                TQ_SLOT(slotSelectSelected()), actionCollection(),
                 "select");
 
     new TDEAction(i18n("Switch to Erase Tool"), "eraser", 0, this,
-                TQT_SLOT(slotEraseSelected()), actionCollection(),
+                TQ_SLOT(slotEraseSelected()), actionCollection(),
                 "erase");
 
     icon = TQIconSet
            (NotePixmapFactory::toTQPixmap(NotePixmapFactory::
                                          makeToolbarPixmap("rest-crotchet")));
     new TDEAction(i18n("Switch to Inserting Rests"), icon, 0, this,
-                TQT_SLOT(slotRestsSelected()), actionCollection(),
+                TQ_SLOT(slotRestsSelected()), actionCollection(),
                 "rests");
 
     createMenu("noteinserter.rc");
 
-    connect(m_parentView, TQT_SIGNAL(changeAccidental(Accidental, bool)),
-            this, TQT_SLOT(slotSetAccidental(Accidental, bool)));
+    connect(m_parentView, TQ_SIGNAL(changeAccidental(Accidental, bool)),
+            this, TQ_SLOT(slotSetAccidental(Accidental, bool)));
 }
 
 NoteInserter::NoteInserter(const TQString& menuName, NotationView* view)
@@ -135,8 +135,8 @@ NoteInserter::NoteInserter(const TQString& menuName, NotationView* view)
         m_lastAccidental(Accidentals::NoAccidental),
         m_followAccidental(false)
 {
-    connect(m_parentView, TQT_SIGNAL(changeAccidental(Accidental, bool)),
-            this, TQT_SLOT(slotSetAccidental(Accidental, bool)));
+    connect(m_parentView, TQ_SIGNAL(changeAccidental(Accidental, bool)),
+            this, TQ_SLOT(slotSetAccidental(Accidental, bool)));
 }
 
 NoteInserter::~NoteInserter()
