@@ -121,35 +121,35 @@ KScope::KScope(TQWidget* pParent, const char* szName) :
 	
 	// Open a file for editing when selected in the project's file list or the
 	// file tree
-	connect(m_pFileView, SIGNAL(fileRequested(const TQString&, uint)), this,
-		SLOT(slotShowEditor(const TQString&, uint)));
+	connect(m_pFileView, TQ_SIGNAL(fileRequested(const TQString&, uint)), this,
+		TQ_SLOT(slotShowEditor(const TQString&, uint)));
 
 	// Delete an editor page object after it is removed
-	connect(m_pEditTabs, SIGNAL(editorRemoved(EditorPage*)),
-		this, SLOT(slotDeleteEditor(EditorPage*)));
+	connect(m_pEditTabs, TQ_SIGNAL(editorRemoved(EditorPage*)),
+		this, TQ_SLOT(slotDeleteEditor(EditorPage*)));
 	
-	connect(m_pEditTabs, SIGNAL(filesDropped(TQDropEvent*)), this,
-		SLOT(slotDropEvent(TQDropEvent*)));
+	connect(m_pEditTabs, TQ_SIGNAL(filesDropped(TQDropEvent*)), this,
+		TQ_SLOT(slotDropEvent(TQDropEvent*)));
 	
 	// Set an editor as the active part whenever its owner tab is selected
-	connect(m_pEditTabs, SIGNAL(editorChanged(EditorPage*, EditorPage*)),
-		this, SLOT(slotChangeEditor(EditorPage*, EditorPage*)));
+	connect(m_pEditTabs, TQ_SIGNAL(editorChanged(EditorPage*, EditorPage*)),
+		this, TQ_SLOT(slotChangeEditor(EditorPage*, EditorPage*)));
 
 	// Display a file at a specific line when selected in a query list
-	connect(m_pQueryWidget, SIGNAL(lineRequested(const TQString&, uint)),
-		this, SLOT(slotQueryShowEditor(const TQString&, uint)));
+	connect(m_pQueryWidget, TQ_SIGNAL(lineRequested(const TQString&, uint)),
+		this, TQ_SLOT(slotQueryShowEditor(const TQString&, uint)));
 	
 	// Display the symbol dialogue when the user opens a new query page
-	connect(m_pQueryWidget, SIGNAL(newQuery()), 
-		this, SLOT(slotQueryReference()));
+	connect(m_pQueryWidget, TQ_SIGNAL(newQuery()), 
+		this, TQ_SLOT(slotQueryReference()));
 
 	// Rebuild the project database after a certain time period has elapsed
 	// since the last save
-	connect(&m_timerRebuild, SIGNAL(timeout()), this, SLOT(slotRebuildDB()));
+	connect(&m_timerRebuild, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotRebuildDB()));
 
 	// Display a file at a specific line when selected in a call tree dialogue
-	connect(m_pCallTreeMgr, SIGNAL(lineRequested(const TQString&, uint)),
-		this, SLOT(slotQueryShowEditor(const TQString&, uint)));
+	connect(m_pCallTreeMgr, TQ_SIGNAL(lineRequested(const TQString&, uint)),
+		this, TQ_SLOT(slotQueryShowEditor(const TQString&, uint)));
 		
 	// Store main window settings when closed
 	setAutoSaveSettings();
@@ -223,8 +223,8 @@ void KScope::initMainWindow()
 
 	// Update the relevant shell action when the dock is hidden through its
 	// close button
-	connect(m_pQueryDock, SIGNAL(headerCloseButtonClicked()), m_pActions,
-		SLOT(slotQueryDockClosed()));
+	connect(m_pQueryDock, TQ_SIGNAL(headerCloseButtonClicked()), m_pActions,
+		TQ_SLOT(slotQueryDockClosed()));
 		
 	// Create the file view dock
 	m_pFileViewDock->setWidget(m_pFileView);
@@ -232,8 +232,8 @@ void KScope::initMainWindow()
 	
 	// Update the relevant shell action when the dock is hidden through its
 	// close button
-	connect(m_pFileViewDock, SIGNAL(headerCloseButtonClicked()), m_pActions,
-		SLOT(slotFileViewDockClosed()));
+	connect(m_pFileViewDock, TQ_SIGNAL(headerCloseButtonClicked()), m_pActions,
+		TQ_SLOT(slotFileViewDockClosed()));
 	
 	// Associate the "Window" menu with the editor tabs widdget
 	pPopup = (TQPopupMenu*)factory()->container("window", this);
@@ -534,8 +534,8 @@ void KScope::slotQueryQuickDef()
 	pDlg = new QueryViewDlg(QueryViewDlg::DestroyOnSelect, this);
 	
 	// Display a line when it is selected in the dialogue
-	connect(pDlg, SIGNAL(lineRequested(const TQString&, uint)), this,
-		SLOT(slotShowEditor(const TQString&, uint)));
+	connect(pDlg, TQ_SIGNAL(lineRequested(const TQString&, uint)), this,
+		TQ_SLOT(slotShowEditor(const TQString&, uint)));
 		
 	// Start the query
 	pDlg->query(nType, sSymbol);
@@ -593,7 +593,7 @@ void KScope::slotConfigure()
 
 	// Apply the preferences if either the "Apply" or the "OK" buttons are
 	// clicked
-	connect(&dlg, SIGNAL(applyPref()), this, SLOT(slotApplyPref()));
+	connect(&dlg, TQ_SIGNAL(applyPref()), this, TQ_SLOT(slotApplyPref()));
 
 	// Show the dialog
 	if (dlg.exec() == TQDialog::Accepted) {
@@ -945,8 +945,8 @@ void KScope::verifyCscope()
 	statusBar()->message(i18n("Verifying Cscope installation..."));
 	
 	pVer = new CscopeVerifier();
-	connect(pVer, SIGNAL(done(bool, uint)), this,
-		SLOT(slotCscopeVerified(bool, uint)));
+	connect(pVer, TQ_SIGNAL(done(bool, uint)), this,
+		TQ_SLOT(slotCscopeVerified(bool, uint)));
 	
 	pVer->verify();
 }
@@ -971,18 +971,18 @@ void KScope::initCscope()
 	m_pCscopeBuild = new CscopeFrontend();
 
 	// Show build progress information in the main status bar
-	connect(m_pCscopeBuild, SIGNAL(progress(int, int)), this,
-		SLOT(slotBuildProgress(int, int)));
-	connect(m_pCscopeBuild, SIGNAL(buildInvIndex()), this,
-		SLOT(slotBuildInvIndex()));
-	connect(m_pCscopeBuild, SIGNAL(finished(uint)), this,
-		SLOT(slotBuildFinished(uint)));
-	connect(m_pCscopeBuild, SIGNAL(aborted()), this,
-		SLOT(slotBuildAborted()));
+	connect(m_pCscopeBuild, TQ_SIGNAL(progress(int, int)), this,
+		TQ_SLOT(slotBuildProgress(int, int)));
+	connect(m_pCscopeBuild, TQ_SIGNAL(buildInvIndex()), this,
+		TQ_SLOT(slotBuildInvIndex()));
+	connect(m_pCscopeBuild, TQ_SIGNAL(finished(uint)), this,
+		TQ_SLOT(slotBuildFinished(uint)));
+	connect(m_pCscopeBuild, TQ_SIGNAL(aborted()), this,
+		TQ_SLOT(slotBuildAborted()));
 
 	// Show errors in a modeless dialogue
-	connect(m_pCscopeBuild, SIGNAL(error(const TQString&)), this,
-		SLOT(slotCscopeError(const TQString&)));
+	connect(m_pCscopeBuild, TQ_SIGNAL(error(const TQString&)), this,
+		TQ_SLOT(slotCscopeError(const TQString&)));
 }
 
 /**
@@ -1174,8 +1174,8 @@ void KScope::slotProjectMake()
 		m_pMakeDlg->setDir(sDir);
 		
 		// Show the relevant source location when an error link is clicked
-		connect(m_pMakeDlg, SIGNAL(fileRequested(const TQString&, uint)), this,
-			SLOT(slotShowEditor(const TQString&, uint)));
+		connect(m_pMakeDlg, TQ_SIGNAL(fileRequested(const TQString&, uint)), this,
+			TQ_SLOT(slotShowEditor(const TQString&, uint)));
 		
 		// Show the dialogue
 		m_pMakeDlg->show();
@@ -1327,20 +1327,20 @@ EditorPage* KScope::createEditorPage()
 	m_pEditTabs->addEditorPage(pPage);
 
 	// Show the file's path in the main title
-	connect(pPage, SIGNAL(fileOpened(EditorPage*, const TQString&)), this,
-		SLOT(slotFileOpened(EditorPage*, const TQString&)));
+	connect(pPage, TQ_SIGNAL(fileOpened(EditorPage*, const TQString&)), this,
+		TQ_SLOT(slotFileOpened(EditorPage*, const TQString&)));
 
 	// Show cursor position in the status bar
-	connect(pPage, SIGNAL(cursorPosChanged(uint, uint)), this,
-		SLOT(slotShowCursorPos(uint, uint)));
+	connect(pPage, TQ_SIGNAL(cursorPosChanged(uint, uint)), this,
+		TQ_SLOT(slotShowCursorPos(uint, uint)));
 	
 	// Rebuild the database after a file has changed
-	connect(pPage, SIGNAL(fileSaved(const TQString&, bool)), this,
-		SLOT(slotFileSaved(const TQString&, bool)));
+	connect(pPage, TQ_SIGNAL(fileSaved(const TQString&, bool)), this,
+		TQ_SLOT(slotFileSaved(const TQString&, bool)));
 	
 	// Handle file drops
-	connect(pPage->getView(), SIGNAL(dropEventPass(TQDropEvent*)), this,
-		SLOT(slotDropEvent(TQDropEvent*)));
+	connect(pPage->getView(), TQ_SIGNAL(dropEventPass(TQDropEvent*)), this,
+		TQ_SLOT(slotDropEvent(TQDropEvent*)));
 
 	// Apply per-project configuration
 	pProj = m_pProjMgr->curProject();
