@@ -74,31 +74,31 @@ LikeBackBar::LikeBackBar(LikeBack *likeBack)
 	m_likeButton->setIconSet(likeIconSet);
 	m_likeButton->setTextLabel("<p>" + i18n("Send application developers a comment about something you like"));
 	m_likeButton->setAutoRaise(true);
-	connect( m_likeButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(clickedLike()) );
+	connect( m_likeButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(clickedLike()) );
 	layout->add(m_likeButton);
 
 	m_dislikeButton = new TQToolButton(this, "likeback_dislike");
 	m_dislikeButton->setIconSet(dislikeIconSet);
 	m_dislikeButton->setTextLabel("<p>" + i18n("Send application developers a comment about something you dislike"));
 	m_dislikeButton->setAutoRaise(true);
-	connect( m_dislikeButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(clickedDislike()) );
+	connect( m_dislikeButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(clickedDislike()) );
 	layout->add(m_dislikeButton);
 
 	m_bugButton = new TQToolButton(this, "likeback_bug");
 	m_bugButton->setIconSet(bugIconSet);
 	m_bugButton->setTextLabel("<p>" + i18n("Send application developers a comment about an improper behavior of the application"));
 	m_bugButton->setAutoRaise(true);
-	connect( m_bugButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(clickedBug()) );
+	connect( m_bugButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(clickedBug()) );
 	layout->add(m_bugButton);
 
 	m_featureButton = new TQToolButton(this, "likeback_feature");
 	m_featureButton->setIconSet(featureIconSet);
 	m_featureButton->setTextLabel("<p>" + i18n("Send application developers a comment about a new feature you desire"));
 	m_featureButton->setAutoRaise(true);
-	connect( m_featureButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(clickedFeature()) );
+	connect( m_featureButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(clickedFeature()) );
 	layout->add(m_featureButton);
 
-	connect( &m_timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(autoMove()) );
+	connect( &m_timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(autoMove()) );
 
 	LikeBack::Button buttons = likeBack->buttons();
 	m_likeButton->setShown(    buttons & LikeBack::Like    );
@@ -125,7 +125,7 @@ void LikeBackBar::autoMove()
 {
 	static TQWidget *lastWindow = 0;
 
-	TQWidget *window = TQT_TQWIDGET(kapp->activeWindow());
+	TQWidget *window = kapp->activeWindow();
 	// When a Kicker applet has the focus, like the Commandline TQLineEdit,
 	// the systemtray icon indicates to be the current window and the LikeBack is shown next to the system tray icon.
 	// It's obviously bad ;-) :
@@ -244,7 +244,7 @@ LikeBack::LikeBack(Button buttons, bool showBarByDefault, TDEConfig *config, con
 
 	// Show the bar if that's wanted by the developer or the user:
 	if (d->showBar)
-		TQTimer::singleShot( 0, d->bar, TQT_SLOT(startTimer()) );
+		TQTimer::singleShot( 0, d->bar, TQ_SLOT(startTimer()) );
 
 #if 0
 	disableBar();
@@ -379,7 +379,7 @@ TDEAction* LikeBack::sendACommentAction(TDEActionCollection *parent)
 	if (d->action == 0)
 		d->action = new TDEAction(
 			i18n("&Send a Comment to Developers"), /*icon=*/"mail-message-new", /*shortcut=*/"",
-			this, TQT_SLOT(execCommentDialog()),
+			this, TQ_SLOT(execCommentDialog()),
 			parent, "likeback_send_a_comment"
 		);
 
@@ -491,7 +491,7 @@ TQString LikeBack::activeWindowPath()
 {
 	// Compute the window hierarchy (from the latest to the oldest):
 	TQStringList windowNames;
-	TQWidget *window = TQT_TQWIDGET(kapp->activeWindow());
+	TQWidget *window = kapp->activeWindow();
 	while (window) {
 		TQString name = window->name();
 		// Append the class name to the window name if it is unnamed:
@@ -559,7 +559,7 @@ void LikeBack::askEmailAddress()
 		"<p><b>" + i18n("Please provide your email address.") + "</b></p>" +
 		"<p>" + i18n("It will only be used to contact you back if more information is needed about your comments, ask you how to reproduce the bugs you report, send bug corrections for you to test, etc.") + "</p>" +
 		"<p>" + i18n("The email address is optional. If you do not provide any, your comments will be sent anonymously.") + "</p>",
-		currentEmailAddress, &ok, TQT_TQWIDGET(kapp->activeWindow()), /*name=*/(const char*)0, &emailValidator);
+		currentEmailAddress, &ok, kapp->activeWindow(), /*name=*/(const char*)0, &emailValidator);
 	enableBar();
 
 	if (ok)
@@ -585,7 +585,7 @@ bool LikeBack::isDevelopmentVersion(const TQString &version)
 		return;
 	m_process = new TDEProcess();
 	*m_process << TQString::fromLatin1("tdecmshell") << TQString::fromLatin1("kcm_useraccount");
-	connect( m_process, TQT_SIGNAL(processExited(TDEProcess*)), TQT_SLOT(fetchUserEmail()) );
+	connect( m_process, TQ_SIGNAL(processExited(TDEProcess*)), TQ_SLOT(fetchUserEmail()) );
 	if (!m_process->start()) {
 		kdDebug() << "Couldn't start tdecmshell.." << endl;
 		delete m_process;
@@ -632,7 +632,7 @@ void LikeBack::fetchUserEmail()
 
 LikeBackDialog::LikeBackDialog(LikeBack::Button reason, const TQString &initialComment, const TQString &windowPath, const TQString &context, LikeBack *likeBack)
  : KDialogBase(KDialogBase::Swallow, i18n("Send a Comment to Developers"), KDialogBase::Ok | KDialogBase::Cancel | KDialogBase::Default,
-               KDialogBase::Ok, TQT_TQWIDGET(kapp->activeWindow()), /*name=*/"_likeback_feedback_window_", /*modal=*/true, /*separator=*/true)
+               KDialogBase::Ok, kapp->activeWindow(), /*name=*/"_likeback_feedback_window_", /*modal=*/true, /*separator=*/true)
  , m_likeBack(likeBack)
  , m_windowPath(windowPath)
  , m_context(context)
@@ -718,11 +718,11 @@ LikeBackDialog::LikeBackDialog(LikeBack::Button reason, const TQString &initialC
 	m_showButtons = new TQCheckBox(i18n("Show comment buttons below &window titlebars"), page);
 	m_showButtons->setChecked(m_likeBack->userWantsToShowBar());
 	pageLayout->addWidget(m_showButtons);
-	connect( m_showButtons, TQT_SIGNAL(stateChanged(int)), this, TQT_SLOT(changeButtonBarVisible()) );
+	connect( m_showButtons, TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(changeButtonBarVisible()) );
 
 	setButtonOK(KGuiItem(i18n("&Send Comment"), "mail-send"));
 	enableButtonOK(false);
-	connect( m_comment, TQT_SIGNAL(textChanged()), this, TQT_SLOT(commentChanged()) );
+	connect( m_comment, TQ_SIGNAL(textChanged()), this, TQ_SLOT(commentChanged()) );
 
 	setButtonGuiItem(Default, KGuiItem(i18n("&Email Address..."), "mail_generic"));
 
@@ -730,7 +730,7 @@ LikeBackDialog::LikeBackDialog(LikeBack::Button reason, const TQString &initialC
 
 	TQAction *sendShortcut = new TQAction(this);
 	sendShortcut->setAccel(TQString("Ctrl+Return"));
-	connect( sendShortcut, TQT_SIGNAL(activated()), actionButton(Ok), TQT_SLOT(animateClick()) );
+	connect( sendShortcut, TQ_SIGNAL(activated()), actionButton(Ok), TQ_SLOT(animateClick()) );
 
 	setMainWidget(page);
 }
@@ -820,7 +820,7 @@ void LikeBackDialog::send()
 
 	std::cout << "http://" << m_likeBack->hostName().local8Bit() << ":" << m_likeBack->hostPort() << m_likeBack->remotePath().local8Bit() << std::endl;
 	std::cout << data.local8Bit() << std::endl;
-	connect( http, TQT_SIGNAL(requestFinished(int, bool)), this, TQT_SLOT(requestFinished(int, bool)) );
+	connect( http, TQ_SIGNAL(requestFinished(int, bool)), this, TQ_SLOT(requestFinished(int, bool)) );
 
 	TQHttpRequestHeader header("POST", m_likeBack->remotePath());
 	header.setValue("Host", m_likeBack->hostName());
